4.39. umbra.ui.common — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.39. umbra.ui.common

common.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines common ui manipulation related objects.

Others:

## 4.39.1. Module Attributes

`umbra.ui.common.` `LOGGER`

## 4.39.2. Functions

`umbra.ui.common.` `getApplicationInstance`()

  This definition returns the current QApplication instance or create one if it doesn’t exists.

  Returns: | Application instance. ( QApplication )

`umbra.ui.common.` `parseLocation`(data)

  This definition parses given location data.

  Parameters: | data – Exception. ( Exception )
  Returns: | Location object. ( Location )

`umbra.ui.common.` `getResourcePath`(name, raiseException=False)

  This definition returns the resource file path matching the given name.

  Parameters: | name – Resource name. ( String ) raiseException – Raise the exception. ( Boolean )
  Returns: | Resource path. ( String )

`umbra.ui.common.` `setWindowDefaultIcon`(window)

  This method sets the default Application icon to the given window.

  Parameters: | window – Window. ( QWidget )
  Returns: | Definition success. ( Boolean )

`umbra.ui.common.` `getSectionsFileParser`(file)

  This method returns a sections file parser.

  Parameters: | file – File. ( String )
  Returns: | Parser. ( SectionsFileParser )

`umbra.ui.common.` `storeLastBrowsedPath`(data)

  This definition is a wrapper method used to store the last browsed path.

  Parameters: | data – Path data. ( QString / QList )
  Returns: | Last browsed path. ( String )

`umbra.ui.common.` `getQVariantAsString`(data)

  This definition returns given QVariant data as a string.

  Parameters: | data – Given data. ( Object )
  Returns: | QVariant data as string. ( String )

`umbra.ui.common.` `parentsWalker`(object)

  This definition is a generator used to retrieve the chain of parents of the given `QObject` instance.

  Parameters: | object – Given path. ( QObject )
  Yield : | Object parent. ( QObject )

`umbra.ui.common.` `signalsBlocker`(instance, attribute, *args, **kwargs)

  This definition blocks given instance signals before calling the given attribute with given arguments and then unblocks the signals.

  Parameters: | instance – Instance object. ( QObject ) attribute – Attribute to call. ( QObject ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )
  Returns: | Object. ( Object )

`umbra.ui.common.` `showWaitCursor`(object)

  This decorator is used to show a wait cursor while processing.

  Parameters: | object – Object to decorate. ( Object )
  Returns: | Object. ( Object )

`umbra.ui.common.` `setToolBoxHeight`(toolBox, height=32)

  This definition sets given height to given QToolBox widget.

  Parameters: | toolbox – ToolBox. ( QToolBox ) height – Height. ( Integer )
  Returns: | Definition success. ( Boolean )

`umbra.ui.common.` `setChildrenPadding`(widget, types, height=None, width=None)

  This definition sets given Widget children padding.

  Parameters: | widget – Widget to sets the children padding. ( QWidget ) types – Children types. ( Tuple / List ) height – Height padding. ( Integer ) width – Width padding. ( Integer )
  Returns: | Definition success. ( Boolean )

## 4.39.3. Classes

class `umbra.ui.common.` `Location`(**kwargs)

  Bases: `foundations.dataStructures.Structure`

  This class represents a storage object for the `SearchInFiles` class location.

  Parameters: | **kwargs – directories, files, filtersIn, filtersOut, targets. ( Key / Value pairs )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »